@@ -1,3 +1,4 @@
+from ocp_resources.constants import TIMEOUT_4MINUTES
 from ocp_resources.resource import NamespacedResource
 
 
@@ -12,6 +13,7 @@ class OperatorGroup(NamespacedResource):
         teardown=True,
         client=None,
         yaml_file=None,
+        delete_timeout=TIMEOUT_4MINUTES,
     ):
         """
         Args:
@@ -23,6 +25,7 @@ class OperatorGroup(NamespacedResource):
             client=client,
             teardown=teardown,
             yaml_file=yaml_file,
+            delete_timeout=delete_timeout,
         )
         self.target_namespaces = target_namespaces
 
